#
# spec file for package libzeitgeist
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2011 Federico Mena Quintero
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libzeitgeist
Version:        0.3.18
Release:        13.3
Summary:        Client library for interacting with the Zeitgeist daemon
License:        LGPL-2.1-or-later
Group:          Productivity/Other
URL:            https://launchpad.net/libzeitgeist
Source0:        %{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)

%description
Libzeitgeist is a client library for interacting with the Zeitgeist
daemon.

%package -n libzeitgeist-1_0-1
Summary:        Client library for interacting with the Zeitgeist daemon
Group:          System/Libraries
Recommends:     zeitgeist

%description -n libzeitgeist-1_0-1
Libzeitgeist is a client library for interacting with the Zeitgeist
daemon.

%package devel
Summary:        Client library for interacting with the Zeitgeist daemon -- Development Files
Group:          Development/Libraries/GNOME
Requires:       libzeitgeist-1_0-1 = %{version}

%description devel
Libzeitgeist is a client library for interacting with the Zeitgeist
daemon.

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# We ship those as %%doc, except INSTALL but we don't care about it
rm %{buildroot}%{_datadir}/doc/libzeitgeist/{AUTHORS,COPYING,INSTALL,MAINTAINERS,README}

%post -n libzeitgeist-1_0-1 -p /sbin/ldconfig
%postun -n libzeitgeist-1_0-1 -p /sbin/ldconfig

%files -n libzeitgeist-1_0-1
%license COPYING
%doc AUTHORS ChangeLog MAINTAINERS NEWS README
%{_libdir}/lib*.so.*

%files devel
%{_includedir}/zeitgeist-1.0/
%{_libdir}/pkgconfig/zeitgeist-1.0.pc
%{_libdir}/lib*.so
%doc %{_datadir}/gtk-doc/
# Own these directories to not depend on vala
%dir %{_datadir}/vala
%{_datadir}/vala/vapi/

%changelog
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Own /usr/share/gtk-doc: glib no longer uses gtk-doc and as a
  consequence cannot be held responsible to deliver that basic
  directory structure.
* Fri Dec 16 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: there is no known consumer of the -32bit
  package.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat May 10 2014 lazy.kent@opensuse.org
- Add baselibs.conf as a source to build -32bit packages.
* Fri Apr  6 2012 vuntz@opensuse.org
- Update to version 0.3.18:
  + Added missing Result Type constant (*CurrentUri and
  * EventOrigin)
  + Now async functions fail instead of lingering indefinitely if
    Zeitgeist isn't available
* Wed Mar 21 2012 vuntz@opensuse.org
- Update to version 0.3.16:
  + Update the list of MIME-type mappings.
* Wed Feb 15 2012 vuntz@opensuse.org
- Update to version 0.3.14:
  + Added new zeitgeist_log_get_default, zeitgeist_log_get_version
    and zeitgeist_index_search_with_relevancies methods
  + Updated ontology and mimetype mapping
  + Added new origin property to ZeitgeistEvent and current_uri
    property to ZeitgeistSubject
  + Make sure Zeitgeist is restarted after it disappears from the
    bus and a ZeitgeistLog method is called
* Thu Sep  8 2011 vuntz@opensuse.org
- Update to version 0.3.12:
  + Fix leaks.
  + Fix unpacking of a gvariant in ZeitgeistDataSourceRegistry.
* Thu May  5 2011 vuntz@opensuse.org
- Update to version 0.3.10:
  + Reference count fix.
  + Documentation fixes.
- Changes from version 0.3.8:
  + Correctly handle get/set for ZeitgeistLog:connected property.
  + Update the zeitgeist-1.0.vapi.
- Changes from version 0.3.6:
  + Relicense under LGPLv2.1+.
- Changes from version 0.3.4:
  + Add new method zeitgeist_data_source_to_variant_full()
  + Remove the gio module: the same functionality has been
    implemented in zeitgeist-datahub.
  + Various bug fixes.
- Change License tag from LGPLv3 to LGPLv2.1+: libzeitgeist got
  relicensed.
- Drop --disable-module configure flag: there is no GIO module
  anymore.
* Tue Apr 26 2011 vuntz@opensuse.org
- Improve summaries and descriptions.
- Remove unneeded gtk-doc BuildRequires.
- Replace zeitgeist Requires with a Recommends, and move it to
  libzeitgeist-1_0-1.
* Wed Jan 12 2011 federico@novell.com
- Split off a libzeitgeist-1_0-1 package for library versioning.
* Wed Jan 12 2011 federico@novell.com
- Split off a -devel package to keep rpmlint happy.
* Tue Jan 11 2011 federico@novell.com
- Initial packaging of libzeitgeist-0.3.2.tar.gz.  This is not split
  into a library and a devel package, because I just want to get
  something working.
